@@ -22,9 +22,12 @@ UNBUILDABLE_IMAGES = {
     # Issues for SHA1 keys:
     # https://github.com/grafana/grafana/issues/41036
     'centos': {
+        "collectd",              # CS10 no opstools repo
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
         "ovsdpdk",               # Not supported on CentOS
+        "redis-base",            # Missing in CS10
+        "telegraf",              # CS10 no opstools repo
         "tgtd",                  # Not supported on CentOS
     },
 
@@ -38,6 +41,8 @@ UNBUILDABLE_IMAGES = {
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
         "ovsdpdk",               # Not supported on CentOS
+        "redis-base",            # Missing in Rocky10
+        "telegraf",              # CS10 no opstools repo
         "tgtd",                  # Not supported on CentOS
     },
 
